from libcpp.string cimport string

cdef extern from "<ostream>" namespace "std":
    cdef cppclass ostream[T]:
        pass

cdef extern from "<sstream>" namespace "std":
    cdef cppclass ostringstream:
        ostringstream() except +
        string str()
        ostream write(char *, size_t)
        ostream write(string)



from Cython.Build import cythonize
from distutils.core import setup, Extension

OPTIMIZED = '-O2'
UNOPTIMIZED = '-O0'
OPTIMIZATION = OPTIMIZED

STATS_EXT = cythonize(Extension("cystatsd.collector.collector", sources=[
        "cystatsd/collector/collector.pyx",
        "cystatsd/collector/statsd_proto.cpp"
    ],
    language="c++",
    include_dirs=["cystatsd/collector"],
    extra_compile_args=[OPTIMIZATION, "--std=c++11"]
))

setup(
    name='cystatsd',
    version='1.0.1',
    description="A c++/cython statsd encoder.  It doesn't make any network calls; it just handles batch encoding.",
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 3'
    ],
    author='Scott Ivey',
    author_email='scott.ivey@gmail.com',
    license='MIT',
    package_data={
        'cystatsd': ['*.pyx', '*.pxd', '*.hpp', '*.pxd', '*.py']
    },
    packages=[
        'cystatsd', 'cystatsd.collector'
    ],
    ext_modules=STATS_EXT,
    provides=['cystatsd']
)



from libcpp.string cimport string
from libcpp.vector cimport vector

#from . cimport cpp_help
#cdef extern from "./statsd_proto.hpp" namespace "statsd_proto":
#    cdef cppclass MetricType:
#        pass


#cdef extern from "./statsd_proto.hpp" namespace "statsd_proto::MetricType":
#    cdef MetricType TIMER
#    cdef MetricType GAUGE
#    cdef MetricType COUNTER

cdef extern from "./statsd_proto.hpp" namespace "statsd_proto":
    #cdef cppclass Metric:
    #    Metric()
    #    Metric(MetricType, string, int)
    #    size_t encodeTo(cpp_help.ostringstream&)

    #cdef cppclass SampledMetric:
    #    SampledMetric()
    #    SampledMetric(Metric, float)
    #    SampledMetric(Metric)
    #    size_t encodeTo(cpp_help.ostringstream&)
    #    string encode()

    cdef cppclass MetricCollector:
        MetricCollector()
        MetricCollector(size_t)
        void pushGauge(const string &name, int value)
        void pushTimer(const string &name, int value)
        void pushCounter(const string &name, int value)
        void pushGauge(const string &name, int value, float rate)
        void pushTimer(const string &name, int value, float rate)
        void pushCounter(const string &name, int value, float rate)
        vector[string] flush()

